Class: Coradoc::CoreModel::Footnote
- Defined in:
- lib/coradoc/core_model/footnote.rb
Overview
Represents a footnote definition in a document
Footnotes are used for auxiliary information, citations, or explanatory notes that appear at the bottom of a page or end of a document.
Instance Attribute Summary collapse
-
#backlink ⇒ Boolean
Whether to include backlink to reference.
-
#content ⇒ String?
The footnote content.
-
#id ⇒ String?
The footnote identifier (e.g., “1”, “fn1”).
-
#inline_content ⇒ Array<String>?
Inline content elements.
Attributes inherited from Base
#element_attributes, #metadata_entries, #title
Method Summary
Methods inherited from Base
#accept, #attr, #metadata, #semantically_equivalent?, #set_attr, #set_metadata
Instance Attribute Details
#backlink ⇒ Boolean
Returns whether to include backlink to reference.
38 |
# File 'lib/coradoc/core_model/footnote.rb', line 38 attribute :backlink, :boolean, default: -> { true } |
#content ⇒ String?
Returns the footnote content.
30 |
# File 'lib/coradoc/core_model/footnote.rb', line 30 attribute :content, :string |
#id ⇒ String?
Returns the footnote identifier (e.g., “1”, “fn1”).
26 |
# File 'lib/coradoc/core_model/footnote.rb', line 26 attribute :id, :string |
#inline_content ⇒ Array<String>?
Returns inline content elements.
34 |
# File 'lib/coradoc/core_model/footnote.rb', line 34 attribute :inline_content, :string, collection: true |